#!/bin/sh

mdir="$1"
action="$2"
domain="$3"

set -e

LE_EXP_PEM="-----BEGIN CERTIFICATE-----
MIIFYDCCBEigAwIBAgIQQAF3ITfU6UK47naqPGQKtzANBgkqhkiG9w0BAQsFADA/
MSQwIgYDVQQKExtEaWdpdGFsIFNpZ25hdHVyZSBUcnVzdCBDby4xFzAVBgNVBAMT
DkRTVCBSb290IENBIFgzMB4XDTIxMDEyMDE5MTQwM1oXDTI0MDkzMDE4MTQwM1ow
TzELMAkGA1UEBhMCVVMxKTAnBgNVBAoTIEludGVybmV0IFNlY3VyaXR5IFJlc2Vh
cmNoIEdyb3VwMRUwEwYDVQQDEwxJU1JHIFJvb3QgWDEwggIiMA0GCSqGSIb3DQEB
AQUAA4ICDwAwggIKAoICAQCt6CRz9BQ385ueK1coHIe+3LffOJCMbjzmV6B493XC
ov71am72AE8o295ohmxEk7axY/0UEmu/H9LqMZshftEzPLpI9d1537O4/xLxIZpL
wYqGcWlKZmZsj348cL+tKSIG8+TA5oCu4kuPt5l+lAOf00eXfJlII1PoOK5PCm+D
LtFJV4yAdLbaL9A4jXsDcCEbdfIwPPqPrt3aY6vrFk/CjhFLfs8L6P+1dy70sntK
4EwSJQxwjQMpoOFTJOwT2e4ZvxCzSow/iaNhUd6shweU9GNx7C7ib1uYgeGJXDR5
bHbvO5BieebbpJovJsXQEOEO3tkQjhb7t/eo98flAgeYjzYIlefiN5YNNnWe+w5y
sR2bvAP5SQXYgd0FtCrWQemsAXaVCg/Y39W9Eh81LygXbNKYwagJZHduRze6zqxZ
Xmidf3LWicUGQSk+WT7dJvUkyRGnWqNMQB9GoZm1pzpRboY7nn1ypxIFeFntPlF4
FQsDj43QLwWyPntKHEtzBRL8xurgUBN8Q5N0s8p0544fAQjQMNRbcTa0B7rBMDBc
SLeCO5imfWCKoqMpgsy6vYMEG6KDA0Gh1gXxG8K28Kh8hjtGqEgqiNx2mna/H2ql
PRmP6zjzZN7IKw0KKP/32+IVQtQi0Cdd4Xn+GOdwiK1O5tmLOsbdJ1Fu/7xk9TND
TwIDAQABo4IBRjCCAUIwDwYDVR0TAQH/BAUwAwEB/zAOBgNVHQ8BAf8EBAMCAQYw
SwYIKwYBBQUHAQEEPzA9MDsGCCsGAQUFBzAChi9odHRwOi8vYXBwcy5pZGVudHJ1
c3QuY29tL3Jvb3RzL2RzdHJvb3RjYXgzLnA3YzAfBgNVHSMEGDAWgBTEp7Gkeyxx
+tvhS5B1/8QVYIWJEDBUBgNVHSAETTBLMAgGBmeBDAECATA/BgsrBgEEAYLfEwEB
ATAwMC4GCCsGAQUFBwIBFiJodHRwOi8vY3BzLnJvb3QteDEubGV0c2VuY3J5cHQu
b3JnMDwGA1UdHwQ1MDMwMaAvoC2GK2h0dHA6Ly9jcmwuaWRlbnRydXN0LmNvbS9E
U1RST09UQ0FYM0NSTC5jcmwwHQYDVR0OBBYEFHm0WeZ7tuXkAXOACIjIGlj26Ztu
MA0GCSqGSIb3DQEBCwUAA4IBAQAKcwBslm7/DlLQrt2M51oGrS+o44+/yQoDFVDC
5WxCu2+b9LRPwkSICHXM6webFGJueN7sJ7o5XPWioW5WlHAQU7G75K/QosMrAdSW
9MUgNTP52GE24HGNtLi1qoJFlcDyqSMo59ahy2cI2qBDLKobkx/J3vWraV0T9VuG
WCLKTVXkcGdtwlfFRjlBz4pYg1htmf5X6DYO8A4jqv2Il9DjXA6USbW1FzXSLr9O
he8Y4IWS6wY7bCkjCWDcRQJMEhg76fsO3txE+FiYruq9RUWhiF1myv4Q6W+CyBFC
Dfvp7OOGAN6dEOM4+qR9sdjoSYKEBpsr6GtPAQw4dy753ec5
-----END CERTIFICATE-----"

fix_le_pubcerts() {
  domain_dir="$1"
  if ! test -d "${domain_dir}"; then
    echo "ERROR: not a directory ${domain_dir}"
    exit 1
  fi
  if ! ls "${domain_dir}/"pubcert*.pem >/dev/null 2>&1; then
    echo "ERROR: no pubcert*.pem in ${domain_dir}"
    exit 1
  fi
  rm -f tmp-pubcert-*
  for pubcert in "${domain_dir}/"pubcert*.pem; do
    cp "${pubcert}" "${pubcert}".orig
    if csplit --version >/dev/null 2>&1; then
      csplit -s -f tmp-pubcert- "${pubcert}" '/-----BEGIN CERTIFICATE-----/' '{*}'
    else
      split -p "-----BEGIN CERTIFICATE-----" "${pubcert}" tmp-pubcert-
    fi
    found=""
    for cert in tmp-pubcert-*; do
      pem=`cat "$cert"`
      if test "$pem" = "$LE_EXP_PEM"; then
        found="$cert"
      fi
    done
    if test -n "$found"; then
      echo "removing expired LE chain in ${pubcert}"
      rm -f  "${pubcert}".tmp
      for cert in tmp-pubcert-*; do
        if test "$cert" != "$found"; then
          cat "$cert" >> "${pubcert}".tmp
        fi
      done
      mv "${pubcert}".tmp "${pubcert}"
    else
      echo "OK: ${pubcert}"
    fi
    rm -f tmp-pubcert-*
  done
}

case "$action" in
    "renewed")
        echo "inspecting cert chains for $domain"
        fix_le_pubcerts "${mdir}/staging/${domain}"
        ;;
    "")
        if test -z "$domain"; then
          # just invoked directly on a directory
          echo "looking for pubcert*pem in $domain"
          fix_le_pubcerts "${mdir}"
        fi
        ;;
    *)
        # ignore other actions
        ;;
esac

